<?php

define('RPC_CONFIG', [
    'app' => env('APP_NAME'),
    'client' => [
        'auth' => [
            'base_uri' => 'http://10.0.2.99',
        ],
    ],
]);

/**
 * 对企业微信群发送报警信息（需先创建
 *
 * @param $chat
 * @param $text
 *
 * @return mixed|null
 */

function chat_text_alert ($chat, $text)
{
    if (env('APP_ENV') == 'local') {
        return true;
    }
    $base_client = new \JsonRpc\Client(RPC_CONFIG);
    $client = $base_client->endpoint('auth');

    try {
        $resp = $client->call('notify.text', [
            ['chat' => $chat],
            $text,
        ]);
    } catch (Exception $ex) {
        return null;
    }

    return $resp;
}

/**
 * 对单个或多个用户发送报警或通知信息，多个用户id使用 | 隔开
 *
 * @param $text
 *
 * @return mixed|null
 */
function user_text_alert ($username, $text)
{
    if (env('APP_ENV') == 'local') {
        return true;
    }
    $base_client = new \JsonRpc\Client(RPC_CONFIG);
    $client = $base_client->endpoint('auth');

    $username = explode('|', $username);
    try {
        $res = $client->call('notify.text', [
            ['user' => $username],
            $text,
        ]);
    } catch (Exception $ex) {
        return null;
    }

    return $res;
}

/**
 * 对微信群发送文本卡片
 *
 * @param $chat
 * @param $title
 * @param $desc
 * @param $button
 * @param $url
 *
 * @return mixed|null
 */
function chat_card_alert ($chat, $title, $desc, $button, $url)
{
    if (env('APP_ENV') == 'local') {
        return true;
    }

    $base_client = new \JsonRpc\Client(RPC_CONFIG);
    $client = $base_client->endpoint('auth');

    try {
        $resp = $client->call('notify.card', [
            ['chat' => $chat],
            $title,
            $desc,
            $button,
            $url,
        ]);
    } catch (Exception $ex) {
        return null;
    }

    return $resp;
}

/**
 * 对单个或多个用户发送文本卡片，多个用户id使用 | 隔开
 *
 * @param $username
 * @param $title
 * @param $desc
 * @param $button
 * @param $url
 *
 * @return mixed|null
 */
function user_card_alert ($username, $title, $desc, $button, $url)
{
    if (env('APP_ENV') == 'local') {
        return true;
    }

    $base_client = new \JsonRpc\Client(RPC_CONFIG);
    $client = $base_client->endpoint('auth');

    $username = explode('|', $username);
    try {
        $resp = $client->call('notify.card', [
            ['user' => $username],
            $title,
            $desc,
            $button,
            $url,
        ]);
    } catch (Exception $ex) {
        return null;
    }

    return $resp;
}

/**
 * 对单个或多个用户发送文本卡片，多个用户id使用 | 隔开
 *
 * @param $username
 * @param $appid //小程序的appid
 * @param $title //标题
 * @param $page //小程序页面路径
 * @param $desc //描述
 * @param $items //消息内容键值对，最多允许10个item
 * @param $emphasisFirstItem //是否放大第一个content_item
 *
 * @return mixed|null
 */
function user_mp_alert ($username, $appid, $title, $page = null, $desc = null, $items = null, $emphasisFirstItem = null)
{
    if (env('APP_ENV') == 'local') {
        return true;
    }

    $base_client = new \JsonRpc\Client(RPC_CONFIG);
    $client = $base_client->endpoint('auth');

    $username = explode('|', $username);
    try {
        $resp = $client->call('notify.mp', [
            ['user' => $username],
            $appid,
            $title,
            $page,
            $desc,
            $items,
            $emphasisFirstItem
        ]);
    } catch (Exception $ex) {
        return null;
    }

    return $resp;
}

/**
 * 对单个或多个用户发送文本卡片，多个用户id使用 | 隔开
 *
 * @param $username
 * @param $appid //小程序的appid
 * @param $title //标题
 * @param $page //小程序页面路径
 * @param $desc //描述
 * @param $items //消息内容键值对，最多允许10个item
 * @param $emphasisFirstItem //是否放大第一个content_item
 *
 * @return mixed|null
 */
function tag_mp_alert ($tag, $appid, $title, $page = null, $desc = null, $items = null, $emphasisFirstItem = null)
{
    if (env('APP_ENV') == 'local') {
        return true;
    }

    $base_client = new \JsonRpc\Client(RPC_CONFIG);
    $client = $base_client->endpoint('auth');

    try {
        $resp = $client->call('notify.mp', [
            ['tag' => $tag],
            $appid,
            $title,
            $page,
            $desc,
            $items,
            $emphasisFirstItem
        ]);
    } catch (Exception $ex) {
        return null;
    }

    return $resp;
}


/**
 * 机器人通知
 *
 *    $content = [
 *      'msgtype' => 'text',
 *      'text' => [
 *          'content' => '!',
 *      ]
 *    ];
 *
 * @param $name
 * @param $content
 * @return array|mixed
 * @throws Exception
 */
function bot_notify($name, $content)
{
    switch ($name) {
        case 'inventory':
            $uri = 'https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=20a40b87-7bb9-4bcf-bd38-6612377d0970';
            break;
        case 'test':
            $uri = 'https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=757bcb2d-913c-4ab6-9395-bfa45f488f68';
            break;
        default:
            throw new Exception('bot name not found!');
    }
    $client = new \GuzzleHttp\Client();
    $option['json'] = $content;
    $resp = $client->request('POST', $uri, $option);
    if ($resp->getStatusCode() == 200) {
        return json_decode($resp->getBody(), true);
    } else {
        return [];
    }
}

/**
 * 对单个或多个用户发送报警或通知图片，多个用户id使用 | 隔开
 *
 * @param $media_id
 *
 * @return mixed|null
 */
function user_image_alert ($username, $media_id)
{
    if (env('APP_ENV') == 'local') {
        return true;
    }
    $base_client = new \JsonRpc\Client(RPC_CONFIG);
    $client = $base_client->endpoint('auth');

    $username = explode('|', $username);
    try {
        $res = $client->call('notify.image', [
            ['user' => $username],
            $media_id,
        ]);
    } catch (Exception $ex) {
        return null;
    }

    return $res;
}

/**
 * 对企业微信群发送报警图片（需先创建
 *
 * @param $chat
 * @param $media_id
 *
 * @return mixed|null
 */

function chat_image_alert ($chat, $media_id)
{
    if (env('APP_ENV') == 'local') {
        return true;
    }
    $base_client = new \JsonRpc\Client(RPC_CONFIG);
    $client = $base_client->endpoint('auth');

    try {
        $resp = $client->call('notify.image', [
            ['chat' => $chat],
            $media_id,
        ]);
    } catch (Exception $ex) {
        return null;
    }

    return $resp;
}